@@ -120,7 +120,7 @@ class ConnectWisdomServiceClient(BaseClient):
         type: Literal["AGENT"],
         clientToken: str = ...,
         description: str = ...,
-        serverSideEncryptionConfiguration: "ServerSideEncryptionConfigurationTypeDef" = ...,
+        serverSideEncryptionConfiguration: ServerSideEncryptionConfigurationTypeDef = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateAssistantResponseTypeDef:
         """
@@ -134,7 +134,7 @@ class ConnectWisdomServiceClient(BaseClient):
         self,
         *,
         assistantId: str,
-        association: "AssistantAssociationInputDataTypeDef",
+        association: AssistantAssociationInputDataTypeDef,
         associationType: Literal["KNOWLEDGE_BASE"],
         clientToken: str = ...,
         tags: Mapping[str, str] = ...
@@ -173,9 +173,9 @@ class ConnectWisdomServiceClient(BaseClient):
         name: str,
         clientToken: str = ...,
         description: str = ...,
-        renderingConfiguration: "RenderingConfigurationTypeDef" = ...,
-        serverSideEncryptionConfiguration: "ServerSideEncryptionConfigurationTypeDef" = ...,
-        sourceConfiguration: "SourceConfigurationTypeDef" = ...,
+        renderingConfiguration: RenderingConfigurationTypeDef = ...,
+        serverSideEncryptionConfiguration: ServerSideEncryptionConfigurationTypeDef = ...,
+        sourceConfiguration: SourceConfigurationTypeDef = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateKnowledgeBaseResponseTypeDef:
         """
@@ -392,7 +392,7 @@ class ConnectWisdomServiceClient(BaseClient):
         self,
         *,
         knowledgeBaseId: str,
-        searchExpression: "SearchExpressionTypeDef",
+        searchExpression: SearchExpressionTypeDef,
         maxResults: int = ...,
         nextToken: str = ...
     ) -> SearchContentResponseTypeDef:
@@ -407,7 +407,7 @@ class ConnectWisdomServiceClient(BaseClient):
         self,
         *,
         assistantId: str,
-        searchExpression: "SearchExpressionTypeDef",
+        searchExpression: SearchExpressionTypeDef,
         maxResults: int = ...,
         nextToken: str = ...
     ) -> SearchSessionsResponseTypeDef:
