@@ -76,7 +76,7 @@ class ListAssistantAssociationsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, assistantId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, assistantId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAssistantAssociationsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#ConnectWisdomService.Paginator.ListAssistantAssociations.paginate)
@@ -91,7 +91,7 @@ class ListAssistantsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAssistantsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#ConnectWisdomService.Paginator.ListAssistants.paginate)
@@ -106,7 +106,7 @@ class ListContentsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, knowledgeBaseId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, knowledgeBaseId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListContentsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#ConnectWisdomService.Paginator.ListContents.paginate)
@@ -121,7 +121,7 @@ class ListKnowledgeBasesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListKnowledgeBasesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#ConnectWisdomService.Paginator.ListKnowledgeBases.paginate)
@@ -136,7 +136,7 @@ class QueryAssistantPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, assistantId: str, queryText: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, assistantId: str, queryText: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[QueryAssistantResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#ConnectWisdomService.Paginator.QueryAssistant.paginate)
@@ -154,8 +154,8 @@ class SearchContentPaginator(Boto3Paginator):
         self,
         *,
         knowledgeBaseId: str,
-        searchExpression: "SearchExpressionTypeDef",
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        searchExpression: SearchExpressionTypeDef,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[SearchContentResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#ConnectWisdomService.Paginator.SearchContent.paginate)
@@ -173,8 +173,8 @@ class SearchSessionsPaginator(Boto3Paginator):
         self,
         *,
         assistantId: str,
-        searchExpression: "SearchExpressionTypeDef",
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        searchExpression: SearchExpressionTypeDef,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[SearchSessionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/wisdom.html#ConnectWisdomService.Paginator.SearchSessions.paginate)
